@@ -48,8 +48,8 @@ class OBJ(object):
         self._parser.parse()
         self._is_parsed = True
 
-    def write(self, mesh, **kwargs):
-        self._writer = OBJWriter(self.filepath, mesh, precision=self.precision, **kwargs)
+    def write(self, mesh, unweld=False, **kwargs):
+        self._writer = OBJWriter(self.filepath, mesh, precision=self.precision, unweld=unweld, **kwargs)
         self._writer.write()
 
     @property
@@ -382,13 +382,14 @@ class OBJParser(object):
 
 class OBJWriter(object):
 
-    def __init__(self, filepath, mesh, precision=None, author=None, email=None, date=None):
+    def __init__(self, filepath, mesh, precision=None, unweld=False, author=None, email=None, date=None):
         self.filepath = filepath
         self.mesh = mesh
         self.author = author
         self.email = email
         self.date = date
         self.precision = precision or compas.PRECISION
+        self.unweld = unweld
         self.vertex_tpl = "v {0:." + self.precision + "}" + " {1:." + self.precision + "}" + " {2:." + self.precision + "}\n"
         self.v = mesh.number_of_vertices()
         self.f = mesh.number_of_faces()
@@ -398,8 +399,11 @@ class OBJWriter(object):
     def write(self):
         with open(self.filepath, 'w') as self.file:
             self.write_header()
-            self.write_vertices()
-            self.write_faces()
+            if self.unweld:
+                self.write_vertices_and_faces()
+            else:
+                self.write_vertices()
+                self.write_faces()
 
     def write_header(self):
         self.file.write("# OBJ\n")
@@ -415,7 +419,6 @@ class OBJWriter(object):
             self.file.write("# date: {}\n".format(self.date))
         self.file.write("\n")
 
-    # this is not the same as adding point objects (like faces)
     def write_vertices(self):
         for key in self.mesh.vertices():
             x, y, z = self.mesh.vertex_coordinates(key)
@@ -429,6 +432,19 @@ class OBJWriter(object):
             vertices_str = " ".join([str(index) for index in vertices])
             self.file.write("f {0}\n".format(vertices_str))
 
+    def write_vertices_and_faces(self):
+        index = 1
+        for face in self.mesh.faces():
+            vertices = self.mesh.face_vertices(face)
+            indices = []
+            for vertex in vertices:
+                x, y, z = self.mesh.vertex_coordinates(vertex)
+                self.file.write(self.vertex_tpl.format(x, y, z))
+                indices.append(index)
+                index += 1
+            indices_str = " ".join([str(i) for i in indices])
+            self.file.write("f {0}\n".format(indices_str))
+
 
 # ==============================================================================
 # Main
